Test Select
open | ../tests/html/test_select.html |
assertSomethingSelected | theSelect |
assertSelected | theSelect | Second Option

Index

select | theSelect | index=4
verifySelectedLabel | theSelect | Fifth Option
verifySelected | theSelect | index=4
verifySelectedLabel | theSelect | Fifth Option
verifySelectedLabels | theSelect | Fifth Option

Label

select | theSelect | Third Option
verifySelected | theSelect | Third Option
verifySelected | theSelect | label=Third Option
verifySelectedLabel | theSelect | Third Option
select | theSelect | label=Fourth Option
verifySelectedLabel | theSelect | Fourth Option
verifySelected | theSelect | Fourth Option

Value

select | theSelect | value=option6
verifySelectedLabel | theSelect | Sixth Option
verifySelectedValue | theSelect | option6
verifySelected | theSelect | value=option6
select | theSelect | value=
verifySelectedLabel | theSelect | Empty Value Option

IDs

select | theSelect | id=o4
verifySelectedLabel | theSelect | Fourth Option
verifySelectedId | theSelect | o4

No text = Empty label

select | theSelect |
verifySelectedLabel | theSelect |
verifySelectedLabels | theSelect |

Select an option that doesn't exist

assertErrorOnNext | Option with label 'Not an option' not found |
select | theSelect | Not an option

Multi-select commands will not work

assertErrorOnNext | Not a multi-select |
addSelection | theSelect | Fourth Option
assertErrorOnNext | Not a multi-select |
removeSelection | theSelect | Fourth Option

assertSelectOptions

verifySelectOptions | theSelect | First Option,Second Option,Third Option,Fourth Option,Fifth Option,Sixth Option,Empty Value Option,